@@ -1,4 +1,7 @@
 import pywikibot
+from requests import Session
+
+session = Session()
 
 url_prop = "P854"
 retrieved_prop = "P813"
